# Notes

## [0.2.3]

- add: kafka support
- chore: document environment variables


## [0.2.2]

- bugfix: default rabbitmq routing key to wildcard


## [0.2.1]

- chore: display host infos in logs 

## [0.2.0]

- add: rabbitmq support


## [0.1.8]

- chore: rename automatic GCP subscription


## [0.1.7]

- chore: move root_logger in App class

## [0.1.5]

- fix: subscription mapping with topic's name
- add: code samples
- add: unittest's skeleton 

